.. _sardana-devel-overview:

========
Overview
========


.. toctree::
    :maxdepth: 2
    
    Global overview <overview>
    Macro Server <overview_macroserver>
    Pool <overview_pool>
    Controller <overview_controller>
    Motor <overview_motor>
    Pseudo motor <overview_pseudomotor>
    IO register <overview_IOR>
    Counter/timer <overview_countertimer>
    0D experiment channel <overview_0D>
    1D experiment channel <overview_1D>
    2D experiment channel <overview_2D>
    Pseudo counter <overview_pseudocounter>

